@@ -1,3 +1,5 @@
+mod test_utils;
+
 #[cfg(feature = "compress")]
 mod d {
     use chrono::{Local, NaiveDateTime};
@@ -12,12 +14,12 @@ mod d {
     use std::fs::File;
     use std::io::{BufRead, BufReader, Write};
     use std::ops::Add;
-    use std::path::PathBuf;
+    use std::path::{Path, PathBuf};
     use std::thread::{self, JoinHandle};
 
     const NO_OF_THREADS: usize = 5;
-    const NO_OF_LOGLINES_PER_THREAD: usize = 1_000_000;
-    const ROTATE_OVER_SIZE: u64 = 30_000_000;
+    const NO_OF_LOGLINES_PER_THREAD: usize = 20_000;
+    const ROTATE_OVER_SIZE: u64 = 600_000;
     const NO_OF_LOG_FILES: usize = 2;
     const NO_OF_GZ_FILES: usize = 5;
 
@@ -27,10 +29,10 @@ mod d {
         // verify that all log lines are written correctly
 
         let start = Local::now();
-        let directory = define_directory();
+        let directory = super::test_utils::dir();
         let logger = Logger::try_with_str("debug")
             .unwrap()
-            .log_to_file(FileSpec::default().directory(directory.clone()));
+            .log_to_file(FileSpec::default().directory(&directory));
 
         #[cfg(not(feature = "async"))]
         let logger = logger.write_mode(WriteMode::BufferAndFlush);
@@ -68,7 +70,7 @@ mod d {
             "Task executed with {} threads in {} ms, writing logs extended to {} ms.",
             NO_OF_THREADS, delta1, delta2
         );
-        verify_logs(&directory);
+        verify_logs(&directory.display().to_string());
     }
 
     // Starts given number of worker threads and lets each execute `do_work`
@@ -82,7 +84,7 @@ mod d {
                     .name(thread_number.to_string())
                     .spawn(move || {
                         do_work(thread_number);
-                        0 as u8
+                        0
                     })
                     .unwrap(),
             );
@@ -112,13 +114,6 @@ mod d {
         trace!("All worker threads joined.");
     }
 
-    fn define_directory() -> String {
-        format!(
-            "./log_files/mt_logs/{}",
-            Local::now().format("%Y-%m-%d_%H-%M-%S")
-        )
-    }
-
     pub fn test_format(
         w: &mut dyn std::io::Write,
         now: &mut DeferredNow,
@@ -185,7 +180,7 @@ mod d {
         write_csv(directory, "thread_4.csv", &counters.threads[4].1);
     }
 
-    fn inspect_file(p: &PathBuf, counters: &mut Counters) {
+    fn inspect_file(p: &Path, counters: &mut Counters) {
         let buf_reader: Box<dyn BufRead> = if p.extension().unwrap() == "gz" {
             Box::new(BufReader::new(GzDecoder::new(BufReader::new(
                 File::open(p).unwrap(),
